@@ -12,7 +12,7 @@ use Capture::Tiny ();
 use File::Path ();
 
 # ABSTRACT: Build shared libraries for use with FFI
-our $VERSION = '0.97_05'; # TRIAL VERSION
+our $VERSION = '0.99_01'; # TRIAL VERSION
 
 
 sub _native_name
@@ -276,7 +276,7 @@ FFI::Build - Build shared libraries for use with FFI
 
 =head1 VERSION
 
-version 0.97_05
+version 0.99_01
 
 =head1 SYNOPSIS
 
@@ -291,7 +291,7 @@ version 0.97_05
  # $lib is an instance of FFI::Build::File::Library
  my $lib = $build->build;
  
- my $ffi = FFI::Platypus->new;
+ my $ffi = FFI::Platypus->new( api => 1 );
  # The filename will be platform dependant, but something like libfrooble.so or frooble.dll
  $ffi->lib($lib->path);
  
