@@ -6,7 +6,7 @@ use constant 1.32 ();
 use FFI::Platypus;
 
 # ABSTRACT: Define constants in C space for Perl
-our $VERSION = '0.97_05'; # TRIAL VERSION
+our $VERSION = '0.99_01'; # TRIAL VERSION
 
 
 {
@@ -65,10 +65,12 @@ FFI::Platypus::Constant - Define constants in C space for Perl
 
 =head1 VERSION
 
-version 0.97_05
+version 0.99_01
 
 =head1 SYNOPSIS
 
+C<ffi/foo.c>:
+
  #include <ffi_platypus_bundle.h>
  
  void
@@ -78,6 +80,21 @@ version 0.97_05
    c->set_str("ABC::DEF", "GHI");  /* sets ABC::DEF to GHI        */
  }
 
+C<lib/Foo.pm>:
+
+ package Foo;
+ 
+ use strict;
+ use warnings;
+ use FFI::Platypus;
+ use base qw( Exporter );
+ 
+ my $ffi = FFI::Platypus->new;
+ # sets constatns Foo::FOO and ABC::DEF from C
+ $ffi->bundle;
+ 
+ 1;
+
 =head1 DESCRIPTION
 
 The Platypus bundle interface (see L<FFI::Platypus::Bundle>) has an entry point
