@@ -5,7 +5,7 @@ use warnings;
 use FFI::Platypus;
 
 # ABSTRACT: An FFI function object
-our $VERSION = '0.97_05'; # TRIAL VERSION
+our $VERSION = '0.99_01'; # TRIAL VERSION
 
 
 use overload '&{}' => sub {
@@ -126,14 +126,14 @@ FFI::Platypus::Function - An FFI function object
 
 =head1 VERSION
 
-version 0.97_05
+version 0.99_01
 
 =head1 SYNOPSIS
 
  use FFI::Platypus;
  
  # call directly
- my $ffi = FFI::Platypus->new;
+ my $ffi = FFI::Platypus->new( api => 1 );
  my $f = $ffi->function(puts => ['string'] => 'int');
  $f->call("hello there");
  
