@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 # ABSTRACT: Documentation and tools for using Platypus with the Assembly
-our $VERSION = '0.97_05'; # TRIAL VERSION
+our $VERSION = '0.99_01'; # TRIAL VERSION
 
 
 sub native_type_map
@@ -26,12 +26,12 @@ FFI::Platypus::Lang::ASM - Documentation and tools for using Platypus with the A
 
 =head1 VERSION
 
-version 0.97_05
+version 0.99_01
 
 =head1 SYNOPSIS
 
  use FFI::Platypus;
- my $ffi = FFI::Platypus->new;
+ my $ffi = FFI::Platypus->new( api => 1 );
  $ffi->lang('ASM');
 
 =head1 DESCRIPTION
