@@ -5,7 +5,7 @@ use warnings;
 use Config;
 
 # ABSTRACT: Documentation and tools for using Platypus with the Windows API
-our $VERSION = '0.97_05'; # TRIAL VERSION
+our $VERSION = '0.99_01'; # TRIAL VERSION
 
 
 sub abi
@@ -187,12 +187,12 @@ FFI::Platypus::Lang::Win32 - Documentation and tools for using Platypus with the
 
 =head1 VERSION
 
-version 0.97_05
+version 0.99_01
 
 =head1 SYNOPSIS
 
  use FFI::Platypus;
- my $ffi = FFI::Platypus->new;
+ my $ffi = FFI::Platypus->new( api => 1 );
  $ffi->lang('Win32');
 
 =head1 DESCRIPTION
