@@ -6,7 +6,7 @@ use Carp qw( croak );
 use base qw( FFI::Platypus::TypeParser );
 
 # ABSTRACT: FFI Type Parser Version One
-our $VERSION = '0.97_05'; # TRIAL VERSION
+our $VERSION = '0.99_01'; # TRIAL VERSION
 
 
 our @CARP_NOT = qw( FFI::Platypus FFI::Platypus::TypeParser );
@@ -14,10 +14,12 @@ our @CARP_NOT = qw( FFI::Platypus FFI::Platypus::TypeParser );
 my %reserved = map { $_ => 1 } qw(
   string
   object
+  type
+  role
+  union
   class
   struct
   record
-  string
   array
   senum
   enum
@@ -285,7 +287,7 @@ FFI::Platypus::TypeParser::Version1 - FFI Type Parser Version One
 
 =head1 VERSION
 
-version 0.97_05
+version 0.99_01
 
 =head1 SYNOPSIS
 
